@@ -759,7 +759,7 @@ do {                                          \
     /* Duff's device */                       \
     uint *_d = (uint*)(dest) + length;         \
     const uint *_s = (uint*)(src) + length;    \
-    register int n = ((length) + 7) / 8;      \
+    int n = ((length) + 7) / 8;               \
     switch ((length) & 0x07)                  \
     {                                         \
     case 0: do { *--_d = *--_s;                 \
@@ -779,7 +779,7 @@ do {                                          \
     /* Duff's device */                       \
     ushort *_d = (ushort*)(dest);         \
     const ushort *_s = (ushort*)(src);    \
-    register int n = ((length) + 7) / 8;      \
+    int n = ((length) + 7) / 8;               \
     switch ((length) & 0x07)                  \
     {                                         \
     case 0: do { *_d++ = *_s++;                 \
