@@ -1,7 +1,7 @@
 /****************************************************************************
 **
 ** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/
+** Contact: http://www.qt-project.org/legal
 **
 ** This file is part of the tools applications of the Qt Toolkit.
 **
@@ -273,8 +273,10 @@ void Generator::beginSubPage(const InnerNode* node, const QString& fileName)
         node->location().fatal(tr("Cannot open output file '%1'").arg(outFile->fileName()));
     QTextStream* out = new QTextStream(outFile);
 
+#ifndef QT_NO_TEXTCODEC
     if (outputCodec)
         out->setCodec(outputCodec);
+#endif
     outStreamStack.push(out);
     const_cast<InnerNode*>(node)->setOutputFileName(fileName);
 }
