@@ -128,7 +128,7 @@ void QQuickContents::calcGeometry(QQuickItem *changed)
 
 class QQuickTransformPrivate : public QObjectPrivate
 {
-    Q_DECLARE_PUBLIC(QQuickTransform);
+    Q_DECLARE_PUBLIC(QQuickTransform)
 public:
     static QQuickTransformPrivate* get(QQuickTransform *transform) { return transform->d_func(); }
 
@@ -894,7 +894,7 @@ QSGNode *QQuickItemPrivate::childContainerNode()
     return groupNode;
 }
 
-Q_DECLARE_OPERATORS_FOR_FLAGS(QQuickItemPrivate::ChangeTypes);
+Q_DECLARE_OPERATORS_FOR_FLAGS(QQuickItemPrivate::ChangeTypes)
 
 QT_END_NAMESPACE
 
